@@ -1,5 +1,5 @@
 #
-# $Id: IPv4.pm 367 2015-02-15 17:11:07Z gomor $
+# $Id: IPv4.pm,v 7609c9d085d3 2018/03/15 15:17:19 gomor $
 #
 package Net::Frame::Layer::IPv4;
 use strict;
@@ -276,7 +276,7 @@ sub computeChecksums {
 our $Next = {
    NF_IPv4_PROTOCOL_ICMPv4()       => 'ICMPv4',
    NF_IPv4_PROTOCOL_IGMP()         => 'IGMP',
-   NF_IPv4_PROTOCOL_IPIP()         => 'IPIP',
+   NF_IPv4_PROTOCOL_IPIP()         => 'IPv4',
    NF_IPv4_PROTOCOL_TCP()          => 'TCP',
    NF_IPv4_PROTOCOL_EGP()          => 'EGP',
    NF_IPv4_PROTOCOL_IGRP()         => 'IGRP',
@@ -589,7 +589,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2018, Patrice E<lt>GomoRE<gt> Auffret
       
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
